@@ -7,7 +7,7 @@ from starlette.datastructures import UploadFile
 
 def test_grobid_xml():
     converter = GrobidConverter()
-    parameters = GrobidParameters()
+    parameters = GrobidParameters(sentences=True, citations=True)
     testdir = Path(__file__).parent
     source = Path(testdir, 'data/PMC1636350.pdf')
     with source.open("rb") as fin:
